@@ -1,13 +1,11 @@
 //! All responses that can be received from the API.
 
-use std::collections::HashSet;
-use std::path::PathBuf;
-
-use chrono::Duration;
-use serde::Deserialize;
+use std::{collections::HashSet, path::PathBuf};
 
 pub use rgb::RGBA8;
 pub use semver::Version as SemVerVersion;
+use serde::Deserialize;
+use time::Duration;
 
 use crate::common::{
     Align, Bounds, Crop, FontFlags, MonitorType, Position, Scale, SceneItem, SceneItemTransform,
@@ -16,6 +14,7 @@ use crate::common::{
 
 mod de;
 
+#[allow(dead_code)]
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "kebab-case")]
 pub(crate) struct Response<T> {
@@ -37,14 +36,14 @@ pub(crate) enum Status {
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "kebab-case")]
 pub struct Version {
-    /// OBSRemote compatible API version. Fixed to 1.1 for retrocompatibility.
+    /// `OBSRemote` compatible API version. Fixed to 1.1 for retro-compatibility.
     pub version: f64,
     /// obs-websocket plugin version.
     pub obs_websocket_version: SemVerVersion,
     /// OBS Studio program version.
     pub obs_studio_version: SemVerVersion,
     /// List of available request types, formatted as a comma-separated list string (e.g. :
-    /// "Method1,Method2,Method3").
+    /// `"Method1,Method2,Method3"`).
     #[serde(deserialize_with = "de::string_comma_list")]
     pub available_requests: HashSet<String>,
     /// List of supported formats for features that use image export (like the
@@ -60,9 +59,9 @@ pub struct Version {
 pub struct AuthRequired {
     /// Indicates whether authentication is required.
     pub auth_required: bool,
-    /// A random string that will be used to generate the auth response.
+    /// A random string that will be used to generate the authentication response.
     pub challenge: Option<String>,
-    /// Applied to the password when generating the auth response.
+    /// Applied to the password when generating the authentication response.
     pub salt: Option<String>,
 }
 
@@ -70,7 +69,7 @@ pub struct AuthRequired {
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "kebab-case")]
 pub(crate) struct FilenameFormatting {
-    /// Current filename formatting string.
+    /// Current file name formatting string.
     pub filename_formatting: String,
 }
 
@@ -217,9 +216,9 @@ pub enum MediaState {
     Paused,
     /// Media stopped.
     Stopped,
-    /// All media in the playlist played.
+    /// All media in the play-list played.
     Ended,
-    /// Error occured while trying to play the media.
+    /// Error occurred while trying to play the media.
     Error,
     /// Unknown state.
     #[serde(other)]
@@ -250,7 +249,7 @@ pub struct MediaSource {
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub(crate) struct SourceItemId {
-    /// ID of the SceneItem in the scene.
+    /// ID of the scene item in the scene.
     pub item_id: i64,
 }
 
@@ -273,7 +272,8 @@ pub(crate) struct SourceTypesList {
 pub struct Volume {
     /// Source name.
     pub name: String,
-    /// Volume of the source. Between `0.0` and `20.0` if using mul, under `26.0` if using dB.
+    /// Volume of the source. Between `0.0` and `20.0` if using **mul**, under `26.0` if using
+    /// **dB**.
     pub volume: f64,
     /// Indicates whether the source is muted.
     pub muted: bool,
@@ -347,9 +347,9 @@ pub struct TextGdiPlusProperties {
     pub color: u32,
     /// Extents wrap.
     pub extents: bool,
-    /// Extents cx.
+    /// Extents `cx`.
     pub extents_cx: i64,
-    /// Extents cy.
+    /// Extents `cy`.
     pub extents_cy: i64,
     /// File path name.
     pub file: PathBuf,
@@ -698,7 +698,7 @@ pub struct StreamingStatus {
     pub recording: bool,
     /// If recording is paused.
     pub recording_paused: bool,
-    /// Always false. Retrocompatibility with OBSRemote.
+    /// Always false. Retro-compatibility with `OBSRemote`.
     #[serde(default)]
     pub preview_only: bool,
     /// Time elapsed since streaming started (only present if currently streaming).
@@ -793,7 +793,7 @@ pub(crate) struct TransitionSettings {
 #[derive(Clone, Debug, Deserialize)]
 #[serde(rename_all = "kebab-case")]
 pub struct ObsStats {
-    /// Current framerate.
+    /// Current frame rate.
     pub fps: f64,
     /// Number of frames rendered.
     pub render_total_frames: u64,
@@ -809,7 +809,7 @@ pub struct ObsStats {
     pub cpu_usage: f64,
     /// Current RAM usage (in megabytes).
     pub memory_usage: f64,
-    /// Free recording disk space (in megabytes)
+    /// Free recording disk space (in megabytes).
     pub free_disk_space: f64,
 }
 
@@ -868,7 +868,7 @@ pub struct Caps {
     pub has_video: bool,
     /// True if sources of this type provide audio.
     pub has_audio: bool,
-    /// True if interaction with this sources of this type is possible.
+    /// True if interaction with sources of this type is possible.
     pub can_interact: bool,
     /// True if sources of this type composite one or more sub-sources.
     pub is_composite: bool,
@@ -888,7 +888,7 @@ pub struct Caps {
 pub struct Font {
     /// Font face.
     pub face: String,
-    /// Font text styling flag. `Bold=1, Italic=2, Bold Italic=3, Underline=5, Strikeout=8`.
+    /// Font text styling flag. `Bold=1, Italic=2, Bold Italic=3, Underline=4, Strikeout=8`.
     #[serde(deserialize_with = "crate::de::bitflags_u8")]
     pub flags: FontFlags,
     /// Font text size.
@@ -931,7 +931,7 @@ pub struct Output {
     pub settings: serde_json::Value,
     /// Output status (active or not).
     pub active: bool,
-    /// Output reconnection status (reconnecting or not).
+    /// Output re-connection status (reconnecting or not).
     pub reconnecting: bool,
     /// Output congestion.
     pub congestion: f64,
@@ -1005,9 +1005,9 @@ pub struct Scene {
 /// part of [`GetStreamSettings`].
 #[derive(Debug, Deserialize)]
 pub struct StreamSettings {
-    /// The publish URL.
+    /// The publishing URL.
     pub server: String,
-    /// The publish key of the stream.
+    /// The publishing key of the stream.
     pub key: String,
     /// Indicates whether authentication should be used when connecting to the streaming server.
     pub use_auth: bool,
