@@ -1,7 +1,6 @@
 #![cfg(feature = "test-integration")]
 
-use std::path::Path;
-use std::time::Duration;
+use std::{path::Path, time::Duration};
 
 use anyhow::Result;
 use futures_util::{pin_mut, StreamExt};
